/*
this file is part of Silenda v0.1 
- Copyright © Alexander Weinhold, 2010

Silenda is a simple command line tool for hiding ASCII-Strings in
(uncompressed) Bitmaps and retrieving them again.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#include <stdio.h>
#include "silenda.h"

void decode(FILE *file) {

	unsigned char tempchar;

	if (feof(file))
		return;

	do {
		tempchar = 0x00;
		int i;

		/* reconstruct char one Bit a time */
		for (i=0; i<8; i++) {
			tempchar = tempchar << 1;
			if ((fgetc(file) & 0x01) != 0)
				tempchar = (tempchar | 0x01);
		}
		putchar(tempchar);
	} while (tempchar != '\0' || feof(file));
	putchar('\n');
}

int main(int argc, char* argv[]) {
	int pictureOffset;
	FILE *file;
	
	if (argc != 2)
		end("Usage: decoder filename");
	if ((file = fopen(argv[1],"rb"))!=NULL) {
		pictureOffset = getPictureOffset(file);

		/* printed to stderr to allow easy separation of output on unix machines */
		fprintf(stderr,"Offset: %d Bytes\n\n", pictureOffset);

		fseek(file,pictureOffset,SEEK_SET);
		decode(file);
		fclose(file);
		return 0;
	}
	else
		end("Could not open file");	
}
